"use client"

import type React from "react"

import { useState } from "react"
import { Button } from "@/components/ui/button"
import { Card, CardContent } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { Textarea } from "@/components/ui/textarea"
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group"
import { Checkbox } from "@/components/ui/checkbox"
import { Calendar } from "@/components/ui/calendar"
import { Popover, PopoverContent, PopoverTrigger } from "@/components/ui/popover"
import { format } from "date-fns"
import { ru } from "date-fns/locale"
import { CalendarIcon, ChevronLeft, Upload } from "lucide-react"
import Link from "next/link"
import { cn } from "@/lib/utils"

export default function WindowWashingForm() {
  const [date, setDate] = useState<Date | undefined>(undefined)
  const [formData, setFormData] = useState({
    title: "",
    description: "",
    address: "",
    windowCount: "",
    windowType: "standard",
    additionalServices: [] as string[],
    budget: "",
    contactMethod: "phone",
    contactInfo: "",
  })

  const handleChange = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
    const { name, value } = e.target
    setFormData((prev) => ({ ...prev, [name]: value }))
  }

  const handleRadioChange = (name: string, value: string) => {
    setFormData((prev) => ({ ...prev, [name]: value }))
  }

  const handleCheckboxChange = (value: string) => {
    setFormData((prev) => {
      const services = [...prev.additionalServices]
      if (services.includes(value)) {
        return { ...prev, additionalServices: services.filter((s) => s !== value) }
      } else {
        return { ...prev, additionalServices: [...services, value] }
      }
    })
  }

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()
    console.log({ ...formData, date })
    // Здесь будет логика отправки данных на сервер
    alert("Задание создано успешно!")
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-6">
        <Link href="/tasks/new" className="flex items-center text-sm text-muted-foreground hover:text-foreground">
          <ChevronLeft className="mr-1 h-4 w-4" />
          Назад к категориям
        </Link>
      </div>

      <div className="mb-8">
        <h1 className="text-2xl font-bold">Мытье окон</h1>
        <p className="text-muted-foreground">Шаг 2 из 4: Заполните детали задания</p>
      </div>

      <form onSubmit={handleSubmit}>
        <div className="grid gap-8 md:grid-cols-2">
          <div className="space-y-6">
            <Card>
              <CardContent className="p-6">
                <div className="space-y-4">
                  <div>
                    <Label htmlFor="title">Название задания</Label>
                    <Input
                      id="title"
                      name="title"
                      placeholder="Например: Помыть окна в квартире"
                      value={formData.title}
                      onChange={handleChange}
                      required
                    />
                  </div>

                  <div>
                    <Label htmlFor="description">Описание задания</Label>
                    <Textarea
                      id="description"
                      name="description"
                      placeholder="Опишите подробно, что нужно сделать..."
                      rows={5}
                      value={formData.description}
                      onChange={handleChange}
                      required
                    />
                  </div>

                  <div>
                    <Label htmlFor="address">Адрес</Label>
                    <Input
                      id="address"
                      name="address"
                      placeholder="Укажите адрес, где нужно выполнить работу"
                      value={formData.address}
                      onChange={handleChange}
                      required
                    />
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card>
              <CardContent className="p-6">
                <h3 className="mb-4 font-medium">Детали задания</h3>
                <div className="space-y-4">
                  <div>
                    <Label htmlFor="windowCount">Количество окон</Label>
                    <Input
                      id="windowCount"
                      name="windowCount"
                      type="number"
                      min="1"
                      placeholder="Укажите количество окон"
                      value={formData.windowCount}
                      onChange={handleChange}
                      required
                    />
                  </div>

                  <div>
                    <Label>Тип окон</Label>
                    <RadioGroup
                      value={formData.windowType}
                      onValueChange={(value) => handleRadioChange("windowType", value)}
                      className="mt-2"
                    >
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="standard" id="standard" />
                        <Label htmlFor="standard">Стандартные</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="panoramic" id="panoramic" />
                        <Label htmlFor="panoramic">Панорамные</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="balcony" id="balcony" />
                        <Label htmlFor="balcony">Балконные</Label>
                      </div>
                    </RadioGroup>
                  </div>

                  <div>
                    <Label className="mb-2 block">Дополнительные услуги</Label>
                    <div className="space-y-2">
                      <div className="flex items-center space-x-2">
                        <Checkbox
                          id="frames"
                          checked={formData.additionalServices.includes("frames")}
                          onCheckedChange={() => handleCheckboxChange("frames")}
                        />
                        <Label htmlFor="frames">Мытье оконных рам</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Checkbox
                          id="sills"
                          checked={formData.additionalServices.includes("sills")}
                          onCheckedChange={() => handleCheckboxChange("sills")}
                        />
                        <Label htmlFor="sills">Мытье подоконников</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <Checkbox
                          id="mosquito"
                          checked={formData.additionalServices.includes("mosquito")}
                          onCheckedChange={() => handleCheckboxChange("mosquito")}
                        />
                        <Label htmlFor="mosquito">Мытье москитных сеток</Label>
                      </div>
                    </div>
                  </div>
                </div>
              </CardContent>
            </Card>
          </div>

          <div className="space-y-6">
            <Card>
              <CardContent className="p-6">
                <h3 className="mb-4 font-medium">Сроки и бюджет</h3>
                <div className="space-y-4">
                  <div>
                    <Label>Дата выполнения</Label>
                    <Popover>
                      <PopoverTrigger asChild>
                        <Button
                          variant="outline"
                          className={cn(
                            "w-full justify-start text-left font-normal mt-1",
                            !date && "text-muted-foreground",
                          )}
                        >
                          <CalendarIcon className="mr-2 h-4 w-4" />
                          {date ? format(date, "PPP", { locale: ru }) : "Выберите дату"}
                        </Button>
                      </PopoverTrigger>
                      <PopoverContent className="w-auto p-0">
                        <Calendar mode="single" selected={date} onSelect={setDate} initialFocus locale={ru} />
                      </PopoverContent>
                    </Popover>
                  </div>

                  <div>
                    <Label htmlFor="budget">Бюджет (₽)</Label>
                    <Input
                      id="budget"
                      name="budget"
                      type="number"
                      min="0"
                      placeholder="Укажите ваш бюджет"
                      value={formData.budget}
                      onChange={handleChange}
                    />
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card>
              <CardContent className="p-6">
                <h3 className="mb-4 font-medium">Контактная информация</h3>
                <div className="space-y-4">
                  <div>
                    <Label>Предпочтительный способ связи</Label>
                    <RadioGroup
                      value={formData.contactMethod}
                      onValueChange={(value) => handleRadioChange("contactMethod", value)}
                      className="mt-2"
                    >
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="phone" id="phone" />
                        <Label htmlFor="phone">Телефон</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="email" id="email" />
                        <Label htmlFor="email">Email</Label>
                      </div>
                      <div className="flex items-center space-x-2">
                        <RadioGroupItem value="messenger" id="messenger" />
                        <Label htmlFor="messenger">Мессенджер</Label>
                      </div>
                    </RadioGroup>
                  </div>

                  <div>
                    <Label htmlFor="contactInfo">Контактные данные</Label>
                    <Input
                      id="contactInfo"
                      name="contactInfo"
                      placeholder={
                        formData.contactMethod === "phone"
                          ? "+7 (XXX) XXX-XX-XX"
                          : formData.contactMethod === "email"
                            ? "example@email.com"
                            : "Ваш username в мессенджере"
                      }
                      value={formData.contactInfo}
                      onChange={handleChange}
                      required
                    />
                  </div>

                  <div>
                    <Label className="mb-2 block">Фотографии (опционально)</Label>
                    <div className="mt-1 flex items-center gap-4">
                      <Button type="button" variant="outline" size="sm">
                        <Upload className="mr-2 h-4 w-4" />
                        Загрузить фото
                      </Button>
                      <span className="text-sm text-muted-foreground">До 5 фотографий</span>
                    </div>
                  </div>
                </div>
              </CardContent>
            </Card>

            <Button type="submit" className="w-full">
              Создать задание
            </Button>
          </div>
        </div>
      </form>
    </div>
  )
}
